==> v1.2.1.zip: dry-types/README.md <==
[gem]: https://rubygems.org/gems/dry-types
[travis]: https://travis-ci.com/dry-rb/dry-types
[codeclimate]: https://codeclimate.com/github/dry-rb/dry-types
[coveralls]: https://coveralls.io/r/dry-rb/dry-types
[inchpages]: http://inch-ci.org/github/dry-rb/dry-types
[chat]: https://dry-rb.zulipchat.com

# dry-types [![Join the chat at https://dry-rb.zulipchat.com](https://img.shields.io/badge/dry--rb-join%20chat-%23346b7a.svg)][chat]

[![Gem Version](https://badge.fury.io/rb/dry-types.svg)][gem]
[![Build Status](https://travis-ci.com/dry-rb/dry-types.svg?branch=master)][travis]
[![Code Climate](https://codeclimate.com/github/dry-rb/dry-types/badges/gpa.svg)][codeclimate]
[![Test Coverage](https://codeclimate.com/github/dry-rb/dry-types/badges/coverage.svg)][codeclimate]
[![Inline docs](http://inch-ci.org/github/dry-rb/dry-types.svg?branch=master)][inchpages]

## Links

* [Documentation](http://dry-rb.org/gems/dry-types)

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `bundle exec rake run_specs` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/dry-rb/dry-types.

==> v1.2.2.zip: dry-types/README.md <==
[gem]: https://rubygems.org/gems/dry-types
[ci]: https://github.com/dry-rb/dry-types/actions?query=workflow%3Aci
[codeclimate]: https://codeclimate.com/github/dry-rb/dry-types
[inchpages]: http://inch-ci.org/github/dry-rb/dry-types
[chat]: https://dry-rb.zulipchat.com

# dry-types [![Join the chat at https://dry-rb.zulipchat.com](https://img.shields.io/badge/dry--rb-join%20chat-%23346b7a.svg)][chat]

[![Gem Version](https://badge.fury.io/rb/dry-types.svg)][gem]
[![Build Status](https://github.com/dry-rb/dry-types/workflows/ci/badge.svg)][ci]
[![Code Climate](https://codeclimate.com/github/dry-rb/dry-types/badges/gpa.svg)][codeclimate]
[![Test Coverage](https://codeclimate.com/github/dry-rb/dry-types/badges/coverage.svg)][codeclimate]
[![Inline docs](http://inch-ci.org/github/dry-rb/dry-types.svg?branch=master)][inchpages]

## Links

- [Documentation](http://dry-rb.org/gems/dry-types)

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `bundle exec rake run_specs` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/dry-rb/dry-types.
